'' +--------------------------------------------------------------------------+
'' | Cluso's Propeller Operating System - OS module: _TYPE    --> _TYPE.CMD   |
'' +--------------------------------------------------------------------------+
'' |  Authors:       (c)2011 by Kwabena W. Agyman (Kye) & J. Moxham (Dr_Acula)|
'' |  Modifications: (c)2012,2013 "Cluso99" (Ray Rodrick)                     |
'' |  License:       MIT License - See end of file for terms of use           |
'' +--------------------------------------------------------------------------+
'' Each module is called from, and returns to, the prop binary "_CMD.CMD"
'' This OS module uses an included module "__MODULE.SPIN" to perform most of
''  the housekeeping - see this for history, details and acknowledgements.
''
'' RR20120317   This module does......
''                Display's a file in ASCII or Hex if H/h modifier is used

'' RR20130708   H/h does not work!

'#include "__MODULE.spin"        ' include the common code for OS modules 
#include "__MODULE.spin"

VAR
  byte  filename0[13]                           ' FAT source filename       (string)
  byte  param[13]                               ' optional parameter(s)

 
DAT
_ModuleStr    byte      "== TYPE ==",0        'module's name (string)
 
PRI executeCommand(stringPointer) | errorString, counter, buffer, flag, i

  'get the parameters
  str.stringCopy(@filename0, str.tokenizeString(0))     ' source filename
  str.stringCopy(@param, str.tokenizeString(0))         ' optional param(s)

  if strsize(@filename0) == 0                           ' if no parameters, display usage
    printStringCR(string(" Display a file..."))
    printStringCR(string("  TYPE <source_filename> [<-h>]"))
    return 0

'-----------------------------------------------------------------
' Open the FAT source file
  errorString := \fat.openfile(@filename0, "R")         ' open source file
  checkError(@filename0, fat.partitionError, errorString) ' if error, display & abort

'-----------------------------------------------------------------
  flag := (str.findCharacter(@param, "H") or str.findCharacter(@param, "h"))

  i~
  repeat until(fat.fileSize == fat.fileTell)
    if(flag)
      printstring(str.integerToHexadecimal(fat.readByte, 2))
      i := i + 2
      if i > (byte[_hub#_OS_Columns]-4)
        i~
        crlf
    else
      PrintChar(ascii(fat.readByte))
  crlf

  fat.closeFile
  return 0

PRI ASCII(ch)
  result := ch & $7F                                    ' remove top bit
  if (result < $20 and result <> $0D and result <> $0A)
    result := "."
  if result == $7F
    result := "."

dat                                                   
{{
+------------------------------------------------------------------------------------------------------------------------------+
|                                                   TERMS OF USE: MIT License                                                  |                                                            
+------------------------------------------------------------------------------------------------------------------------------+
|Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation    | 
|files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    |
|modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software|
|is furnished to do so, subject to the following conditions:                                                                   |
|                                                                                                                              |
|The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.|
|                                                                                                                              |
|THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          |
|WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         |
|COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   |
|ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         |
+------------------------------------------------------------------------------------------------------------------------------+
}} 